package com.fastbee.data.controller.anfang.service;

import com.fastbee.common.model.bto.DoorAlertBto;
import com.fastbee.iot.model.anfang.UploadedPhotos;

import java.util.List;

/**
 * 存储上传的照片信息Service接口
 * 
 * @author kerwincui
 * @date 2024-06-20
 */
public interface IUploadedPhotosService 
{
    /**
     * 查询存储上传的照片信息
     * 
     * @param id 存储上传的照片信息主键
     * @return 存储上传的照片信息
     */
    public UploadedPhotos selectUploadedPhotosById(Long id);

    /**
     * 查询存储上传的照片信息列表
     * 
     * @param uploadedPhotos 存储上传的照片信息
     * @return 存储上传的照片信息集合
     */
    public List<UploadedPhotos> selectUploadedPhotosList(UploadedPhotos uploadedPhotos);

    /**
     * 新增存储上传的照片信息
     * 
     * @param uploadedPhotos 存储上传的照片信息
     * @return 结果
     */
    public int insertUploadedPhotos(UploadedPhotos uploadedPhotos);

    /**
     * 修改存储上传的照片信息
     * 
     * @param uploadedPhotos 存储上传的照片信息
     * @return 结果
     */
    public int updateUploadedPhotos(UploadedPhotos uploadedPhotos);

    /**
     * 批量删除存储上传的照片信息
     * 
     * @param ids 需要删除的存储上传的照片信息主键集合
     * @return 结果
     */
    public int deleteUploadedPhotosByIds(Long[] ids);

    /**
     * 删除存储上传的照片信息信息
     * 
     * @param id 存储上传的照片信息主键
     * @return 结果
     */
    public int deleteUploadedPhotosById(Long id);

    /**
     * 抓拍监控照片
     * @param sn
     * @return
     */
    String captureMonitorPhoto(String sn);

    /**
     * 发送短信通知
     * @param sn
     * @param doorState
     * @param shakeState
     */
    void sendAlarmMessage(String sn, String doorState, String shakeState,String eventType);

    String doorAlert(DoorAlertBto doorAlertBto) throws Exception;

    int uploadPicByTime(UploadedPhotos uploadedPhotos);
}
