package com.fastbee.data.controller.gis.water;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.ggroup.domain.GSiteReservoirInfo;
import com.fastbee.ggroup.service.IGSiteReservoirInfoService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 水库站点基础信息Controller
 *
 * @author kerwincui
 * &#064;date  2024-10-23
 */
@RestController
@RequestMapping("/gis/site/reservoir/info")
@Api(tags = "水库站点基础信息")
public class GSiteReservoirInfoController extends BaseController
{
    @Autowired
    private IGSiteReservoirInfoService gSiteReservoirInfoService;

    /**
     * 获取根据站点id获取水库站点基础信息详细信息
     */
//    @PreAuthorize("@ss.hasPermi('ggroup:info:query')")
    @GetMapping(value = "/{siteId}")
    @ApiOperation("获取水库站点基础信息详细信息")
    public AjaxResult getInfo(@PathVariable("siteId") Long siteId)
    {
        return AjaxResult.success(gSiteReservoirInfoService.selectGSiteReservoirInfoBySiteId(siteId));
    }

    /**
     * 修改水库站点基础信息
     */
//    @PreAuthorize("@ss.hasPermi('ggroup:info:edit')")
    @PutMapping
    @ApiOperation("修改水库站点基础信息")
    public AjaxResult edit(@RequestBody GSiteReservoirInfo gSiteReservoirInfo)
    {
        return toAjax(gSiteReservoirInfoService.updateGSiteReservoirInfo(gSiteReservoirInfo));
    }
}
