package com.fastbee.data.controller.gis.water;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.ggroup.domain.GSiteRiverInfo;
import com.fastbee.ggroup.service.IGSiteRiverInfoService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 河流基础信息Controller
 *
 * @author kerwincui
 * @date 2024-10-22
 */
@RestController
@RequestMapping("/gis/site/river/info")
@Api(tags = "河流基础信息")
public class GSiteRiverInfoController extends BaseController
{
    @Autowired
    private IGSiteRiverInfoService gRiverInfoService;


    /**
     * 根据站点id获取河流基本信息
     */
//    @PreAuthorize("@ss.hasPermi('ggroup:info:list')")
    @GetMapping("/byStationId/{stationId}")
    @ApiOperation("根据站点id获取河流基本信息")
    public AjaxResult listByStationId(@PathVariable("stationId") Long siteId){

        return AjaxResult.success(gRiverInfoService.selectGRiverInfoBySiteId(siteId));
    }


    /**
     * 修改河流基础信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:edit')")
    @PutMapping
    @ApiOperation("修改河流基础信息")
    public AjaxResult edit(@RequestBody GSiteRiverInfo gSiteRiverInfo)
    {
        return toAjax(gRiverInfoService.updateGRiverInfo(gSiteRiverInfo));
    }


}
