package com.fastbee.crop.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.crop.mapper.AgricultureCropYieldMapper;
import com.fastbee.crop.domain.AgricultureCropYield;
import com.fastbee.crop.service.IAgricultureCropYieldService;

/**
 * 作物产量记录Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-11-26
 */
@Service
public class AgricultureCropYieldServiceImpl implements IAgricultureCropYieldService 
{
    @Autowired
    private AgricultureCropYieldMapper agricultureCropYieldMapper;

    /**
     * 查询作物产量记录
     * 
     * @param id 作物产量记录主键
     * @return 作物产量记录
     */
    @Override
    public AgricultureCropYield selectAgricultureCropYieldById(Long id)
    {
        return agricultureCropYieldMapper.selectAgricultureCropYieldById(id);
    }

    /**
     * 查询作物产量记录列表
     * 
     * @param agricultureCropYield 作物产量记录
     * @return 作物产量记录
     */
    @Override
    public List<AgricultureCropYield> selectAgricultureCropYieldList(AgricultureCropYield agricultureCropYield)
    {
        return agricultureCropYieldMapper.selectAgricultureCropYieldList(agricultureCropYield);
    }

    /**
     * 新增作物产量记录
     * 
     * @param agricultureCropYield 作物产量记录
     * @return 结果
     */
    @Override
    public int insertAgricultureCropYield(AgricultureCropYield agricultureCropYield)
    {
        return agricultureCropYieldMapper.insertAgricultureCropYield(agricultureCropYield);
    }

    /**
     * 修改作物产量记录
     * 
     * @param agricultureCropYield 作物产量记录
     * @return 结果
     */
    @Override
    public int updateAgricultureCropYield(AgricultureCropYield agricultureCropYield)
    {
        return agricultureCropYieldMapper.updateAgricultureCropYield(agricultureCropYield);
    }

    /**
     * 批量删除作物产量记录
     * 
     * @param ids 需要删除的作物产量记录主键
     * @return 结果
     */
    @Override
    public int deleteAgricultureCropYieldByIds(Long[] ids)
    {
        return agricultureCropYieldMapper.deleteAgricultureCropYieldByIds(ids);
    }

    /**
     * 删除作物产量记录信息
     * 
     * @param id 作物产量记录主键
     * @return 结果
     */
    @Override
    public int deleteAgricultureCropYieldById(Long id)
    {
        return agricultureCropYieldMapper.deleteAgricultureCropYieldById(id);
    }
}
