package com.fastbee.ggroup.domain;

import java.math.BigDecimal;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.fastbee.common.annotation.Excel;
import com.fastbee.common.core.domain.BaseEntity;

/**
 * 水库站点基础信息对象 g_site_reservoir_info
 *
 * @author kerwincui
 * @date 2024-10-23
 */
@ApiModel(value = "GSiteReservoirInfo",description = "水库站点基础信息 g_site_reservoir_info")
@Data
@EqualsAndHashCode(callSuper = true)
public class GSiteReservoirInfo extends BaseEntity
        {
private static final long serialVersionUID = 1L;

    /** 主键ID */
    private Long id;

    /** 工程名称 */
            @Excel(name = "工程名称")
            @ApiModelProperty("工程名称")
    private String projectName;

    /** 地理坐标 */
            @Excel(name = "地理坐标")
            @ApiModelProperty("地理坐标")
    private String geoCoordinates;

    /** 工程位置 */
            @Excel(name = "工程位置")
            @ApiModelProperty("工程位置")
    private String projectLocation;

    /** 所在流域 */
            @Excel(name = "所在流域")
            @ApiModelProperty("所在流域")
    private String drainageBasin;

    /** 所在水系 */
            @Excel(name = "所在水系")
            @ApiModelProperty("所在水系")
    private String drainageSystem;

    /** 所在河流 */
            @Excel(name = "所在河流")
            @ApiModelProperty("所在河流")
    private String river;

    /** 所在乡镇/村 */
            @Excel(name = "所在乡镇/村")
            @ApiModelProperty("所在乡镇/村")
    private String townVillage;

    /** 水库类型 */
            @Excel(name = "水库类型")
            @ApiModelProperty("水库类型")
    private String reservoirType;

    /** 水库功能 */
            @Excel(name = "水库功能")
            @ApiModelProperty("水库功能")
    private String reservoirFunction;

    /** 工程建设情况 */
            @Excel(name = "工程建设情况")
            @ApiModelProperty("工程建设情况")
    private String constructionStatus;

    /** 水库级别 */
            @Excel(name = "水库级别")
            @ApiModelProperty("水库级别")
    private String reservoirLevel;

    /** 主坝级别 */
            @Excel(name = "主坝级别")
            @ApiModelProperty("主坝级别")
    private String mainDamLevel;

    /** 主坝尺寸坝高 */
            @Excel(name = "主坝尺寸坝高")
            @ApiModelProperty("主坝尺寸坝高")
    private BigDecimal mainDamHeight;

    /** 主坝尺寸坝长 */
            @Excel(name = "主坝尺寸坝长")
            @ApiModelProperty("主坝尺寸坝长")
    private BigDecimal mainDamLength;

    /** 坝顶高程 */
            @Excel(name = "坝顶高程")
            @ApiModelProperty("坝顶高程")
    private BigDecimal damCrestElevation;

    /** 正常蓄水位 */
            @Excel(name = "正常蓄水位")
            @ApiModelProperty("正常蓄水位")
    private BigDecimal normalStorageLevel;

    /** 死水位 */
            @Excel(name = "死水位")
            @ApiModelProperty("死水位")
    private BigDecimal deadWaterLevel;

    /** 总库容 */
            @Excel(name = "总库容")
            @ApiModelProperty("总库容")
    private Long totalCapacity;

    /** 兴利库容 */
            @Excel(name = "兴利库容")
            @ApiModelProperty("兴利库容")
    private Long beneficialCapacity;

    /** 死库容 */
            @Excel(name = "死库容")
            @ApiModelProperty("死库容")
    private Long deadStorage;

    /** 正常蓄水位相应水面面积 */
            @Excel(name = "正常蓄水位相应水面面积")
            @ApiModelProperty("正常蓄水位相应水面面积")
    private Integer normalStorageArea;

    /** 设计年供水量 */
            @Excel(name = "设计年供水量")
            @ApiModelProperty("设计年供水量")
    private Long annualSupplyCapacity;

    /** 行政责任人 */
            @Excel(name = "行政责任人")
            @ApiModelProperty("行政责任人")
    private String administrativeResponsible;

    /** 行政责任人单位名称 */
            @Excel(name = "行政责任人单位名称")
            @ApiModelProperty("行政责任人单位名称")
    private String administrativeUnitName;

    /** 行政责任人职务 */
            @Excel(name = "行政责任人职务")
            @ApiModelProperty("行政责任人职务")
    private String administrativePosition;

    /** 行政责任人电话 */
            @Excel(name = "行政责任人电话")
            @ApiModelProperty("行政责任人电话")
    private String administrativePhone;

    /** 技术责任人 */
            @Excel(name = "技术责任人")
            @ApiModelProperty("技术责任人")
    private String technicalResponsible;

    /** 技术责任人单位名称 */
            @Excel(name = "技术责任人单位名称")
            @ApiModelProperty("技术责任人单位名称")
    private String technicalUnitName;

    /** 技术责任人职务 */
            @Excel(name = "技术责任人职务")
            @ApiModelProperty("技术责任人职务")
    private String technicalPosition;

    /** 技术责任人电话 */
            @Excel(name = "技术责任人电话")
            @ApiModelProperty("技术责任人电话")
    private String technicalPhone;

    /** 巡查责任人 */
            @Excel(name = "巡查责任人")
            @ApiModelProperty("巡查责任人")
    private String inspectionResponsible;

    /** 巡查责任人单位名称 */
            @Excel(name = "巡查责任人单位名称")
            @ApiModelProperty("巡查责任人单位名称")
    private String inspectionUnitName;

    /** 巡查责任人职务 */
            @Excel(name = "巡查责任人职务")
            @ApiModelProperty("巡查责任人职务")
    private String inspectionPosition;

    /** 巡查责任人电话 */
            @Excel(name = "巡查责任人电话")
            @ApiModelProperty("巡查责任人电话")
    private String inspectionPhone;

    /** 创建人 */
            @Excel(name = "创建人")
            @ApiModelProperty("创建人")
    private String createdBy;

    /** 更新人 */
            @Excel(name = "更新人")
            @ApiModelProperty("更新人")
    private String updatedBy;

    /** 删除标志（0:正常,2:删除） */
    private Integer delFlag;

    /** 所属站点ID */
            @Excel(name = "所属站点ID")
            @ApiModelProperty("所属站点ID")
    private Long siteId;

}
